@@ -1,8 +1,8 @@
 """Structure factor and scattering from radial distribution functions"""
 
 # Add imports here
-#from .grsq import *
-#from .damping import Damping
+from .grsq import *
+from .damping import Damping
 from .debye import *
 
 #from ._version import __version__
