@@ -3,7 +3,7 @@ import numpy as np
 from scipy.integrate import cumtrapz
 from scipy.optimize import least_squares
 from collections import OrderedDict
-from .debye import Debye
+#from .debye import Debye
 
 class RDF:
     ''' RDF Object.
